---
title: <span class="badge builder"></span> CustomRoleRef
---
# <span class="badge builder"></span> CustomRoleRef

## Constructor

```python
CustomRoleRef()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> rolebinding.CustomRoleRef
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [CustomRoleRef](./object-CustomRoleRef.md)
